@@ -283,10 +283,11 @@ class dyn_obj:
                 int_curveOB.data.use_fill_caps = True
 
                 int_curveOB.data.bevel_factor_start = 0
+                int_curveOB.name = 'tmp'
 
                 curve_to_mesh(int_curveOB)
 
-                tmp_curve_mesh = bpy.data.objects[self.name+'_streamline']
+                tmp_curve_mesh = bpy.data.objects['tmp']
                 
                 bpy.context.view_layer.objects.active = tmp_curve_mesh
                 self.streamline.select_set(state=True)
